==> fuel-ui-0.0.13.tgz: package/src/components/Pagination/Pagination.ts <==
import {Component, View, ElementRef, Input, Output, EventEmitter, OnChanges, ChangeDetectionStrategy} from 'angular2/core';
import {CORE_DIRECTIVES, SlicePipe} from 'angular2/common';
import {Range} from '../../pipes/Range/Range';

@Component({
    selector: 'pagination',
    changeDetection: ChangeDetectionStrategy.OnPush,
    properties: [
        "totalPages: total-pages",
        "pagesAtOnce: pages-at-once"
    ]
})
@View({
    styleUrls: ['components/Pagination/Pagination.css'],
    templateUrl: 'components/Pagination/Pagination.html',
    directives: [CORE_DIRECTIVES],
    pipes: [SlicePipe, Range]
})
export class Pagination implements OnChanges {
    private _el:HTMLElement;
    @Input() currentPage: number;
    @Input() pagesAtOnce: number;
    @Input() totalPages: number;
    @Output() currentPageChange = new EventEmitter<any>();
    pagesBlank:Array<number> = [];
    startingIndex:number;
    endingIndex:number;

    constructor(el: ElementRef){
        this._el = el.nativeElement;
    }

    ngOnChanges(changes:any):void{
        this.setPage(this.currentPage);
    }

    getElement(): HTMLElement{
        return this._el;
    }

    setPage(newPage:number):void{
        if(newPage < 1 || newPage > this.totalPages) return;

        this.currentPage = newPage;

        //Shift pagination stuffs
        if(this.currentPage - Math.ceil(this.pagesAtOnce / 2) < 0 || this.totalPages - this.pagesAtOnce <= 0){
            this.startingIndex = 0;
            this.endingIndex = this.pagesAtOnce;
        }
        else if(this.totalPages - this.currentPage <= this.pagesAtOnce - Math.ceil(this.pagesAtOnce / 2)) {
            this.startingIndex = this.totalPages - this.pagesAtOnce;
            this.endingIndex = this.totalPages;
        }
        else {
            this.startingIndex = this.currentPage - Math.ceil(this.pagesAtOnce / 2);
            this.endingIndex = this.startingIndex + this.pagesAtOnce < this.totalPages
                                ? this.startingIndex + this.pagesAtOnce
                                : this.totalPages;
        }

        this.currentPageChange.next(this.currentPage);
    }
}

export var PAGINATION_PROVIDERS = [
    Pagination
];

==> fuel-ui-0.1.8.tgz: package/src/components/Pagination/Pagination.ts <==
import {Component, ElementRef, Input, Output, EventEmitter, OnChanges, ChangeDetectionStrategy} from 'angular2/core';
import {CORE_DIRECTIVES, SlicePipe} from 'angular2/common';
import {RangePipe} from '../../pipes/Range/Range';

@Component({
    selector: 'pagination',
    changeDetection: ChangeDetectionStrategy.OnPush,
    properties: [
        "totalPages: total-pages",
        "pagesAtOnce: pages-at-once"
    ],
    styleUrls: ['components/Pagination/Pagination.css'],
    templateUrl: 'components/Pagination/Pagination.html',
    directives: [CORE_DIRECTIVES],
    pipes: [SlicePipe, RangePipe]
})
export class Pagination implements OnChanges {
    @Input() currentPage: number = 1;
    @Input() pagesAtOnce: number = 5;
    @Input() totalPages: number = 10;
    @Output() currentPageChange = new EventEmitter<any>();
    pagesBlank:Array<number> = [];
    startingIndex:number;
    endingIndex:number;

    constructor(){
        this.setPage(this.currentPage);
    }

    ngOnChanges(changes:any):void{
        this.setPage(this.currentPage);
    }

    setPage(newPage:number):void{
        if(newPage < 1 || newPage > this.totalPages) return;

        this.currentPage = newPage;

        //Shift pagination stuffs
        if(this.currentPage - Math.ceil(this.pagesAtOnce / 2) < 0 || this.totalPages - this.pagesAtOnce <= 0){
            this.startingIndex = 0;
            this.endingIndex = this.pagesAtOnce;
        }
        else if(this.totalPages - this.currentPage <= this.pagesAtOnce - Math.ceil(this.pagesAtOnce / 2)) {
            this.startingIndex = this.totalPages - this.pagesAtOnce;
            this.endingIndex = this.totalPages;
        }
        else {
            this.startingIndex = this.currentPage - Math.ceil(this.pagesAtOnce / 2);
            this.endingIndex = this.startingIndex + this.pagesAtOnce < this.totalPages
                                ? this.startingIndex + this.pagesAtOnce
                                : this.totalPages;
        }

        this.currentPageChange.next(this.currentPage);
    }
}

export var PAGINATION_PROVIDERS = [
    Pagination
];
